summaryrefslogtreecommitdiffstats
path: root/kpilot/kpilot/kroupware.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/kpilot/kroupware.cc')
-rw-r--r--kpilot/kpilot/kroupware.cc66
1 files changed, 33 insertions, 33 deletions
diff --git a/kpilot/kpilot/kroupware.cc b/kpilot/kpilot/kroupware.cc
index fc57b4b5..212df17d 100644
--- a/kpilot/kpilot/kroupware.cc
+++ b/kpilot/kpilot/kroupware.cc
@@ -30,7 +30,7 @@
#include "options.h"
-#include <qfile.h>
+#include <tqfile.h>
#include <dcopclient.h>
#include <ktempfile.h>
@@ -71,7 +71,7 @@ void KroupwareSync::cleanupConfig()
KConfig* c = KPilotSettings::self()->config();
c->setGroup("todoOptions");
if ( c->hasKey( "CalFileBackup") ) {
- QString fn = c->readPathEntry( "CalFileBackup" );
+ TQString fn = c->readPathEntry( "CalFileBackup" );
if ( fn != CSL1("empty") ) {
c->writePathEntry( "CalFile" ,fn );
c->writeEntry( "CalFileBackup" , "empty" );
@@ -79,7 +79,7 @@ void KroupwareSync::cleanupConfig()
}
c->setGroup("vcalOptions");
if ( c->hasKey( "CalFileBackup") ) {
- QString fn = c->readPathEntry( "CalFileBackup" );
+ TQString fn = c->readPathEntry( "CalFileBackup" );
if ( fn != CSL1("empty") ) {
c->writePathEntry( "CalFile" ,fn );
c->writeEntry( "CalFileBackup" , "empty" );
@@ -103,14 +103,14 @@ void KroupwareSync::start_syncCal_TodosWithKMail( bool cal, bool todos )
KConfig*c = KPilotSettings::self()->config();
DCOPClient *client = kapp->dcopClient();
KTempFile tempfile;
- QString filename = tempfile.name();
- QByteArray data, reply_data;
- QCString reply_type;
- QDataStream arg(data, IO_WriteOnly);
+ TQString filename = tempfile.name();
+ TQByteArray data, reply_data;
+ TQCString reply_type;
+ TQDataStream arg(data, IO_WriteOnly);
arg << filename;
if (!client->call( "kmail" ,
"KOrganizerSyncIface",
- "pullSyncData(QString)",
+ "pullSyncData(TQString)",
data,
reply_type,
reply_data)) {
@@ -125,7 +125,7 @@ void KroupwareSync::start_syncCal_TodosWithKMail( bool cal, bool todos )
if ( todos ) {
logMessage( i18n("Syncing to-dos with KMail" ));
c->setGroup("todoOptions");
- QString fn = c->readPathEntry( "CalFile" );
+ TQString fn = c->readPathEntry( "CalFile" );
c->writePathEntry( "CalFileBackup" ,fn );
c->writePathEntry( "CalFile" ,filename );
}
@@ -134,7 +134,7 @@ void KroupwareSync::start_syncCal_TodosWithKMail( bool cal, bool todos )
if ( cal ) {
logMessage( i18n("Syncing calendar with KMail" ));
c->setGroup("vcalOptions");
- QString fn = c->readPathEntry( "CalFile" );
+ TQString fn = c->readPathEntry( "CalFile" );
c->writePathEntry( "CalFileBackup" ,fn );
c->writePathEntry( "CalFile" ,filename );
}
@@ -149,14 +149,14 @@ void KroupwareSync::start_syncAddWithKMail()
logMessage( CSL1("Syncing Addresses with KMail" ));
DCOPClient *client = kapp->dcopClient();
KTempFile tempfile;
- QString filename = tempfile.name();
- QByteArray data, reply_data;
- QCString reply_type;
- QDataStream arg(data, IO_WriteOnly);
+ TQString filename = tempfile.name();
+ TQByteArray data, reply_data;
+ TQCString reply_type;
+ TQDataStream arg(data, IO_WriteOnly);
arg << filename;
if (!client->call( "kmail" ,
"KMailIface",
- "requestAddresses(QString)",
+ "requestAddresses(TQString)",
data,
reply_type,
reply_data)) {
@@ -182,7 +182,7 @@ void KroupwareSync::end_syncCal_TodosWithKMail( bool cal, bool todos)
{
if ( !cal && ! todos )
return;
- QString filename;
+ TQString filename;
KConfig*c=KPilotSettings::self()->config();
if ( todos ) {
logMessage( i18n("Rewriting to-dos to KMail..." ));
@@ -195,7 +195,7 @@ void KroupwareSync::end_syncCal_TodosWithKMail( bool cal, bool todos)
logMessage( i18n("Rewriting Calendar to KMail" ));
c->setGroup("vcalOptions");
filename = c->readPathEntry( "CalFile" );
- QString tf = c->readPathEntry( "CalFileBackup" ) ;
+ TQString tf = c->readPathEntry( "CalFileBackup" ) ;
c->writePathEntry( "CalFile" , tf );
c->writeEntry( "CalFileBackup" ,"empty");
}
@@ -204,13 +204,13 @@ void KroupwareSync::end_syncCal_TodosWithKMail( bool cal, bool todos)
logMessage(CSL1("Try to call KMail via DCOP to finish sync..."));
// try DCOP connection to KMail
DCOPClient *client = kapp->dcopClient();
- QByteArray data, reply_data;
- QCString reply_type;
- QDataStream arg(data, IO_WriteOnly);
+ TQByteArray data, reply_data;
+ TQCString reply_type;
+ TQDataStream arg(data, IO_WriteOnly);
arg << filename;
if (!client->call( "kmail" /*"korganizer" kmdcop */,
"KOrganizerSyncIface",
- "pushSyncData(QString)",
+ "pushSyncData(TQString)",
data,
reply_type,
reply_data)) {
@@ -222,7 +222,7 @@ void KroupwareSync::end_syncCal_TodosWithKMail( bool cal, bool todos)
logMessage(CSL1("Calling over DCOP succeeded"));
logMessage(CSL1("Sync to KMail has finished successfully"));
}
- QFile::remove( filename );
+ TQFile::remove( filename );
}
}
void KroupwareSync::end_syncAddWithKMail()
@@ -232,17 +232,17 @@ void KroupwareSync::end_syncAddWithKMail()
// TODO!! better config handling (KConfig XT)
KConfig*c = KPilotSettings::self()->config();
c->setGroup("Abbrowser-conduit");
- QString filename = c->readPathEntry( "KMailTempFile" );
+ TQString filename = c->readPathEntry( "KMailTempFile" );
c->writeEntry( "KMailTempFile" , "empty" );
KPilotSettings::writeConfig();
- QByteArray data, reply_data;
- QCString reply_type;
- QDataStream arg(data, IO_WriteOnly);
+ TQByteArray data, reply_data;
+ TQCString reply_type;
+ TQDataStream arg(data, IO_WriteOnly);
arg << filename;
- arg << QStringList();
+ arg << TQStringList();
if (!client->call( "kmail" ,
"KMailIface",
- "storeAddresses(QString, QStringList)",
+ "storeAddresses(TQString, TQStringList)",
data,
reply_type,
reply_data)) {
@@ -252,7 +252,7 @@ void KroupwareSync::end_syncAddWithKMail()
else {
logMessage(CSL1("Calling store addresses over DCOP succeeded"));
}
- //QFile::remove( filename );
+ //TQFile::remove( filename );
}
void KroupwareSync::end_syncNotesWithKMail()
{
@@ -262,16 +262,16 @@ void KroupwareSync::end_syncNotesWithKMail()
/* static */ bool KroupwareSync::startKMail(QString *error)
{
FUNCTIONSETUP;
- QCString kmdcop;
- QString mess;
+ TQCString kmdcop;
+ TQString mess;
int pid;
return KApplication::startServiceByDesktopName(CSL1("kmail"),
- QString::null,
+ TQString::null,
error,
&kmdcop,
&pid
@@ -262,16 +262,16 @@ void KroupwareSync::end_syncNotesWithKMail()
{
-/* static */ bool KroupwareSync::startKMail(QString *error)
+/* static */ bool KroupwareSync::startKMail(TQString *error)
{
FUNCTIONSETUP;